@@ -1,5 +1,5 @@
 from flask import Blueprint
-from .renderer import render_field, csrf_setup
+from .jinja_globals import render_field, csrf_setup
 from .filters import (
     timesince,
     local_date,
@@ -58,4 +58,8 @@ class Boilerplate(object):
         # Setup App Debug via Sentry (When in production)
         if use_sentry and not app.debug:
             from raven.contrib.flask import Sentry
-            app.sentry = Sentry(app)
\ No newline at end of file
+            app.sentry = Sentry(app)
+
+
+
+
